# Working with NeoPixels
import board
import neopixel
import time, digitalio
from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile
from audiomp3 import MP3Decoder

from adafruit_led_animation.color import (
    AMBER, #(255, 100, 0)
    AQUA, # (50, 255, 255)
    BLACK, #OFF (0, 0, 0)
    BLUE, # (0, 0, 255)
    CYAN, # (0, 255, 255)
    GOLD, # (255, 222, 30)
    GREEN, # (0, 255, 0)
    JADE, # (0, 255, 40)
    MAGENTA, #(255, 0, 20)
    OLD_LACE, # (253, 245, 230)
    ORANGE, # (255, 40, 0)
    PINK, # (242, 90, 255)
    PURPLE, # (180, 0, 255)
    RED, # (255, 0, 0)
    TEAL, # (0, 255, 120)
    WHITE, # (255, 255, 255)
    YELLOW, # (255, 150, 0)
    RAINBOW # a list of colors to cycle through
    # RAINBOW is RED, ORANGE, YELLOW, GREEN, BLUE, and PURPLE ((255, 0, 0), (255, 40, 0), (255, 150, 0), (0, 255, 0), (0, 0, 255), (180, 0, 255))
)

INDIGO = (63,0,255)
VIOLET = (127,0,255)
colors = [RED, MAGENTA, ORANGE, YELLOW, GREEN, JADE, BLUE, INDIGO, VIOLET]


pixels_pin = board.NEOPIXEL
pixels_num_of_lights = 10
pixels = neopixel.NeoPixel(pixels_pin, pixels_num_of_lights, brightness = 0.5, auto_write=True)

strip_pin = board.A1
strip_num_of_lights = 30
strip = neopixel.NeoPixel(strip_pin, strip_num_of_lights, brightness = 0.5, auto_write=True)

strip_lights_per_neopixel = int(strip_num_of_lights / pixels_num_of_lights)

button_A = digitalio.DigitalInOut(board.BUTTON_A)
button_A.switch_to_input(pull=digitalio.Pull.DOWN)

# set up the speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

#set up the path where sound files can be found
path = "sounds/"


try:
    from audioio import AudioOut
except ImportError:
    try:
        from audiopwmio import PWMAudioOut as AudioOut
    except ImportError:
        print("This board does not support AudioOut")

filename = "carHorn.mp3"
mp3_file = open(path + filename, "rb")
decoder = MP3Decoder(mp3_file)

def play_mp3(filename, numb):
    decoder.file = open(path + filename, "rb")
    audio.play(decoder)
    while audio.playing:
        if numb == 1:
            lightsOn(RED, 2)
        elif numb == 2:
            disco()
        else:
            pass

def play_sound(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            pass

def lightsOn(lightColor, numTimes):
    counter = 0
    while counter < numTimes:
        strip.fill(lightColor)
        time.sleep(0.3)
        strip.fill(BLACK)
        time.sleep(0.3)
        counter = counter + 1

def disco():
    for i in range(0,9):
        strip.fill(colors[i])
        time.sleep(0.1)
        strip.fill(BLACK)
        time.sleep(0.1)
while True:
    if(button_A.value):
        time.sleep(17) #17
        lightsOn(JADE, 3)
        play_sound("success.wav")
        time.sleep(3)
        play_mp3("carHorn.mp3", 1)
        time.sleep(4)
        play_mp3("marioKart.mp3", 2)



